@@ -1,19 +1,15 @@
 #!/usr/bin/env python3
 
 import argparse
-import pathlib
+import re
+from pathlib import Path
 
 parser = argparse.ArgumentParser()
-parser.add_argument(
-    "--source", "-i", type=pathlib.Path, required=True, help="ctags's output"
-)
-parser.add_argument(
-    "--out", "-o", type=pathlib.Path, required=True, help="header to generate"
-)
+parser.add_argument("--source", "-i", type=Path, required=True, help="ctags's output")
+parser.add_argument("--out", "-o", type=Path, required=True, help="header to generate")
 
 shargs = parser.parse_args()
-
-
+externC_regex = re.compile(r'extern\s+"C"')
 with open(shargs.source, "r") as infile:
     with open(shargs.out, "w") as outfile:
         for line in infile:
@@ -24,7 +20,11 @@ with open(shargs.source, "r") as infile:
             fields = line.split("\t")
             kind = fields[3].split(":", 1)[1]
             if kind == "function":
+                decl = ""
+                externC = externC_regex.search(fields[2])
+                if externC:
+                    decl = 'extern "C" '
                 symname = fields[0]
                 signature = fields[5].split(":", 1)[1]
                 rtype = fields[6].split(":", 1)[1]
-                print(f"{rtype} {symname}{signature};", file=outfile)
+                print(f"{decl}{rtype} {symname}{signature};", file=outfile)
