@@ -5,51 +5,31 @@
   ******************************************************************************
   * @attention
   *
-  * <h2><center>&copy; COPYRIGHT(c) 2016 STMicroelectronics</center></h2>
+  * Copyright (c) 2016-2021, STMicroelectronics
+  * All rights reserved.
   *
-  * Redistribution and use in source and binary forms, with or without modification,
-  * are permitted provided that the following conditions are met:
-  *   1. Redistributions of source code must retain the above copyright notice,
-  *      this list of conditions and the following disclaimer.
-  *   2. Redistributions in binary form must reproduce the above copyright notice,
-  *      this list of conditions and the following disclaimer in the documentation
-  *      and/or other materials provided with the distribution.
-  *   3. Neither the name of STMicroelectronics nor the names of its contributors
-  *      may be used to endorse or promote products derived from this software
-  *      without specific prior written permission.
-  *
-  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
   *
   ******************************************************************************
   */
 
 #include "stm32_eeprom.h"
+#include "stm32yyxx_ll_utils.h"
 #include <string.h>
+#include <stdbool.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /* Be able to change FLASH_BANK_NUMBER to use if relevant */
-#if !defined(FLASH_BANK_NUMBER) &&\
-    (defined(STM32F0xx) || defined(STM32F1xx) || defined(STM32G4xx) ||\
-     defined(STM32H7xx) || defined(STM32L4xx) || defined(STM32L5xx))
-/* For STM32F0xx, FLASH_BANK_1 is not defined only FLASH_BANK1_END is defined */
-#if defined(STM32F0xx)
-#define FLASH_BANK_1 1U
-#endif
+#if !defined(FLASH_BANK_NUMBER) && defined(FLASH_BANK_1) && !defined(STM32WBAxx)
 #if defined(FLASH_BANK_2)
 #define FLASH_BANK_NUMBER   FLASH_BANK_2
-#else
+#else /* FLASH_BANK_1 */
 #define FLASH_BANK_NUMBER   FLASH_BANK_1
 #endif /* FLASH_BANK_2 */
 #ifndef FLASH_BANK_NUMBER
@@ -58,67 +38,52 @@ extern "C" {
 #endif /* !FLASH_BANK_NUMBER */
 
 /* Be able to change FLASH_DATA_SECTOR to use if relevant */
-#if defined(STM32F2xx) || defined(STM32F4xx) || defined(STM32F7xx) ||\
-    defined(STM32H7xx)
+#if defined(FLASH_SECTOR_TOTAL) || defined(FLASH_SECTOR_NB)
 #if !defined(FLASH_DATA_SECTOR)
+#if defined(FLASH_SECTOR_TOTAL)
 #define FLASH_DATA_SECTOR   ((uint32_t)(FLASH_SECTOR_TOTAL - 1))
+#elif defined(FLASH_SECTOR_NB)
+#define FLASH_DATA_SECTOR   ((uint32_t)(FLASH_SECTOR_NB - 1))
+#endif
 #else
 #ifndef FLASH_BASE_ADDRESS
 #error "FLASH_BASE_ADDRESS have to be defined when FLASH_DATA_SECTOR is defined"
 #endif
 #endif /* !FLASH_DATA_SECTOR */
-#endif /* STM32F2xx || STM32F4xx || STM32F7xx */
+#endif /* FLASH_SECTOR_TOTAL || FLASH_SECTOR_NB */
 
-/* Be able to change FLASH_PAGE_NUMBER to use if relevant */
-#if !defined(FLASH_PAGE_NUMBER) &&\
-    (defined (STM32G0xx) || defined(STM32G4xx) || defined (STM32L4xx) ||\
-     defined (STM32L5xx) || defined(STM32WBxx))
-#define FLASH_PAGE_NUMBER   ((uint32_t)((FLASH_SIZE / FLASH_PAGE_SIZE) - 1))
-#endif /* !FLASH_PAGE_NUMBER */
+/* Be able to change EEPROM_FLASH_PAGE_NUMBER to use if relevant */
+#if !defined(EEPROM_FLASH_PAGE_NUMBER) && defined(FLASH_PAGE_SIZE)
+#if defined(STM32WB0x) || defined(STM32WL3x)
+/* STM32WB0x and STM32WL3 define the FLASH_PAGE_NUMBER */
+#define EEPROM_FLASH_PAGE_NUMBER   (FLASH_PAGE_NUMBER - 1)
+#else
+#define EEPROM_FLASH_PAGE_NUMBER   ((uint32_t)(((LL_GetFlashSize() * 1024) / FLASH_PAGE_SIZE) - 1))
+#endif
+#endif /* !EEPROM_FLASH_PAGE_NUMBER */
 
 /* Be able to change FLASH_END to use */
 #if !defined(FLASH_END)
-#if defined (STM32F0xx) || defined (STM32F1xx)
-#if defined (FLASH_BANK2_END) && (FLASH_BANK_NUMBER == FLASH_BANK_2)
-#define FLASH_END  FLASH_BANK2_END
-#elif defined (FLASH_BANK1_END) && (FLASH_BANK_NUMBER == FLASH_BANK_1)
-#define FLASH_END  FLASH_BANK1_END
-#endif
-#elif defined (STM32F3xx)
-static inline uint32_t get_flash_end(void)
-{
-  uint32_t size;
-  switch ((*((uint16_t *)FLASH_SIZE_DATA_REGISTER))) {
-    case 0x200U:
-      size = 0x0807FFFFU;
-      break;
-    case 0x100U:
-      size = 0x0803FFFFU;
-      break;
-    case 0x80U:
-      size = 0x0801FFFFU;
-      break;
-    case 0x40U:
-      size = 0x0800FFFFU;
-      break;
-    case 0x20U:
-      size = 0x08007FFFU;
-      break;
-    default:
-      size = 0x08003FFFU;
-      break;
-  }
-  return size;
-}
-#define FLASH_END  get_flash_end()
-#elif defined(STM32G0xx) || defined(STM32G4xx) || defined (STM32L4xx) || \
-      defined (STM32L5xx) || defined(STM32WBxx)
-/* If FLASH_PAGE_NUMBER is defined by user, this is not really end of the flash */
-#define FLASH_END  ((uint32_t)(FLASH_BASE + (((FLASH_PAGE_NUMBER +1) * FLASH_PAGE_SIZE))-1))
-#elif defined(EEPROM_RETRAM_MODE)
+#if defined(EEPROM_RETRAM_MODE)
 #define FLASH_END  ((uint32_t)(EEPROM_RETRAM_START_ADDRESS + EEPROM_RETRAM_MODE_SIZE -1))
 #elif defined(DATA_EEPROM_END)
 #define FLASH_END DATA_EEPROM_END
+#elif defined (FLASH_BANK2_END) && (FLASH_BANK_NUMBER == FLASH_BANK_2)
+#define FLASH_END  FLASH_BANK2_END
+#elif defined (FLASH_BANK1_END) && (FLASH_BANK_NUMBER == FLASH_BANK_1)
+#define FLASH_END  FLASH_BANK1_END
+#elif defined(FLASH_DATA_SECTOR)
+#if defined(FLASH_BANK_2) && (FLASH_BANK_NUMBER == FLASH_BANK_2)
+#define FLASH_END  ((uint32_t)(FLASH_BASE + FLASH_BANK_SIZE + (FLASH_DATA_SECTOR * FLASH_SECTOR_SIZE) + FLASH_SECTOR_SIZE - 1))
+#else
+#define FLASH_END  ((uint32_t)(FLASH_BASE + (FLASH_DATA_SECTOR * FLASH_SECTOR_SIZE) + FLASH_SECTOR_SIZE - 1))
+#endif /* FLASH_BANK_2 */
+#elif defined(FLASH_START_ADDR)
+/* If EEPROM_FLASH_PAGE_NUMBER is defined by user, this is not really end of the flash */
+#define FLASH_END  ((uint32_t)(FLASH_START_ADDR + (((EEPROM_FLASH_PAGE_NUMBER +1) * FLASH_PAGE_SIZE))-1))
+#elif defined(FLASH_BASE) && defined(EEPROM_FLASH_PAGE_NUMBER) && defined (FLASH_PAGE_SIZE)
+/* If EEPROM_FLASH_PAGE_NUMBER is defined by user, this is not really end of the flash */
+#define FLASH_END  ((uint32_t)(FLASH_BASE + (((EEPROM_FLASH_PAGE_NUMBER +1) * FLASH_PAGE_SIZE))-1))
 #endif
 #ifndef FLASH_END
 #error "FLASH_END could not be defined"
@@ -129,7 +94,7 @@ static inline uint32_t get_flash_end(void)
 #ifndef FLASH_BASE_ADDRESS
 /*
  * By default, Use the last page of the flash to store data
- * in order to prevent overwritting
+ * in order to prevent overwriting
  * program data
  */
 #if defined(EEPROM_RETRAM_MODE)
@@ -218,7 +183,25 @@ void eeprom_buffered_write_byte(uint32_t pos, uint8_t value)
   */
 void eeprom_buffer_fill(void)
 {
+#if defined(ICACHE) && defined (HAL_ICACHE_MODULE_ENABLED) && !defined(HAL_ICACHE_MODULE_DISABLED)
+  bool icache_enabled = false;
+  if (HAL_ICACHE_IsEnabled() == 1) {
+    icache_enabled = true;
+    /* Disable instruction cache prior to internal cacheable memory update */
+    if (HAL_ICACHE_Disable() != HAL_OK) {
+      Error_Handler();
+    }
+  }
+#endif /* ICACHE && HAL_ICACHE_MODULE_ENABLED && !HAL_ICACHE_MODULE_DISABLED */
   memcpy(eeprom_buffer, (uint8_t *)(FLASH_BASE_ADDRESS), E2END + 1);
+#if defined(ICACHE) && defined (HAL_ICACHE_MODULE_ENABLED) && !defined(HAL_ICACHE_MODULE_DISABLED)
+  if (icache_enabled) {
+    /* Re-enable instruction cache */
+    if (HAL_ICACHE_Enable() != HAL_OK) {
+      Error_Handler();
+    }
+  }
+#endif /* ICACHE && HAL_ICACHE_MODULE_ENABLED && !HAL_ICACHE_MODULE_DISABLED */
 }
 
 #if defined(EEPROM_RETRAM_MODE)
@@ -242,66 +225,107 @@ void eeprom_buffer_flush(void)
   */
 void eeprom_buffer_flush(void)
 {
+#if defined(ICACHE) && defined (HAL_ICACHE_MODULE_ENABLED) && !defined(HAL_ICACHE_MODULE_DISABLED)
+  bool icache_enabled = false;
+  if (HAL_ICACHE_IsEnabled() == 1) {
+    icache_enabled = true;
+    /* Disable instruction cache prior to internal cacheable memory update */
+    if (HAL_ICACHE_Disable() != HAL_OK) {
+      Error_Handler();
+    }
+  }
+#endif /* ICACHE && HAL_ICACHE_MODULE_ENABLED && !HAL_ICACHE_MODULE_DISABLED */
   FLASH_EraseInitTypeDef EraseInitStruct;
   uint32_t offset = 0;
   uint32_t address = FLASH_BASE_ADDRESS;
   uint32_t address_end = FLASH_BASE_ADDRESS + E2END;
-#if defined (STM32F0xx) || defined (STM32F1xx) || defined (STM32F3xx) || \
-    defined (STM32G0xx) || defined (STM32G4xx) || \
-    defined (STM32L4xx) || defined (STM32L5xx) || defined (STM32WBxx)
+#if defined(FLASH_TYPEERASE_PAGES)
   uint32_t pageError = 0;
+#if defined(FLASH_TYPEPROGRAM_QUADWORD)
+  uint64_t data[2] = {0x0000};
+#elif defined(FLASH_TYPEPROGRAM_DOUBLEWORD)
+#if defined(STM32U3xx)
+  uint32_t dataAddr = 0;
+#else
+  /* Double word*/
   uint64_t data = 0;
+#endif /* STM32U3xx */
+#elif defined(FLASH_TYPEPROGRAM_WORD)
+  uint32_t data = 0;
+#endif
 
   /* ERASING page */
   EraseInitStruct.TypeErase = FLASH_TYPEERASE_PAGES;
-#if defined (STM32F1xx) || defined (STM32G4xx) || defined (STM32L4xx) || \
-    defined (STM32L5xx)
+#if defined(FLASH_BANK_NUMBER)
   EraseInitStruct.Banks = FLASH_BANK_NUMBER;
-#endif
-#if defined (STM32G0xx) || defined (STM32G4xx) || defined (STM32L4xx) || \
-    defined (STM32L5xx) || defined (STM32WBxx)
-  EraseInitStruct.Page = FLASH_PAGE_NUMBER;
+#endif /* FLASH_BANK_NUMBER */
+#if defined (EEPROM_FLASH_PAGE_NUMBER) && defined(FLASH_SIZE)
+  EraseInitStruct.Page = EEPROM_FLASH_PAGE_NUMBER;
 #else
   EraseInitStruct.PageAddress = FLASH_BASE_ADDRESS;
 #endif
   EraseInitStruct.NbPages = 1;
-
-  if (HAL_FLASH_Unlock() == HAL_OK) {
-#if defined (STM32G0xx) || defined (STM32G4xx) || defined (STM32L4xx) || \
-      defined (STM32L5xx) || defined (STM32WBxx)
-    __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_ALL_ERRORS);
-#else
-    __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_EOP | FLASH_FLAG_WRPERR | FLASH_FLAG_PGERR);
+#if !defined(PROT_LEVEL_NONE) && !defined(STM32WL3x)
+  if (HAL_FLASH_Unlock() == HAL_OK)
+    /* TODO: else HAL_FLASHEx_PageProtection? */
 #endif
+  {
+    __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_ALL_ERRORS);
     if (HAL_FLASHEx_Erase(&EraseInitStruct, &pageError) == HAL_OK) {
       while (address <= address_end) {
+#if defined(FLASH_TYPEPROGRAM_QUADWORD)
+        /* 128 bits */
+        memcpy(&data, eeprom_buffer + offset, 4 * sizeof(uint32_t));
+        if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_QUADWORD, address, (uint32_t)data) == HAL_OK) {
+          address += 16;
+          offset += 16;
+#elif defined(FLASH_TYPEPROGRAM_DOUBLEWORD)
+        /* 64 bits */
+#if defined(STM32U3xx)
+        dataAddr = (uint32_t)((uint8_t *)eeprom_buffer + offset);
 
+        if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_DOUBLEWORD, address, dataAddr) == HAL_OK) {
+#else
         data = *((uint64_t *)((uint8_t *)eeprom_buffer + offset));
 
         if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_DOUBLEWORD, address, data) == HAL_OK) {
+#endif
           address += 8;
           offset += 8;
+#elif defined(FLASH_TYPEPROGRAM_WORD)
+        /* 32 bits */
+        memcpy(&data, eeprom_buffer + offset,  sizeof(uint32_t));
+        if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_WORD, address, (uint32_t)data) == HAL_OK) {
+          address += 4;
+          offset += 4;
+#endif
         } else {
           address = address_end + 1;
         }
       }
     }
+#if !defined(PROT_LEVEL_NONE) && !defined(STM32WL3x)
     HAL_FLASH_Lock();
+#endif
   }
-#else
+#else /* FLASH_TYPEERASE_SECTORS */
   uint32_t SectorError = 0;
-#if defined(STM32H7xx)
+#if defined(FLASH_TYPEPROGRAM_FLASHWORD)
   uint64_t data[4] = {0x0000};
+#elif defined(FLASH_TYPEPROGRAM_QUADWORD)
+  uint32_t data[4] = {0x0000};
 #else
   uint32_t data = 0;
 #endif
 
   /* ERASING page */
   EraseInitStruct.TypeErase = FLASH_TYPEERASE_SECTORS;
-#if defined(STM32H7xx)
+#if defined(FLASH_BANK_NUMBER)
   EraseInitStruct.Banks = FLASH_BANK_NUMBER;
 #endif
+#if defined(FLASH_VOLTAGE_RANGE_3)
   EraseInitStruct.VoltageRange = FLASH_VOLTAGE_RANGE_3;
+#endif
   EraseInitStruct.Sector = FLASH_DATA_SECTOR;
   EraseInitStruct.NbSectors = 1;
 
@@ -309,17 +333,26 @@ void eeprom_buffer_flush(void)
 
   if (HAL_FLASHEx_Erase(&EraseInitStruct, &SectorError) == HAL_OK) {
     while (address <= address_end) {
-#if defined(STM32H7xx)
+#if defined(FLASH_TYPEPROGRAM_FLASHWORD)
       /* 256 bits */
       memcpy(&data, eeprom_buffer + offset, 8 * sizeof(uint32_t));
       if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_FLASHWORD, address, (uint32_t)data) == HAL_OK) {
         address += 32;
         offset += 32;
-#else
+#elif defined(FLASH_TYPEPROGRAM_QUADWORD)
+      /* 128 bits */
+      memcpy(&data, eeprom_buffer + offset, 4 * sizeof(uint32_t));
+      if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_QUADWORD, address, (uint32_t)data) == HAL_OK) {
+        address += 16;
+        offset += 16;
+#elif defined(FLASH_TYPEPROGRAM_WORD)
       memcpy(&data, eeprom_buffer + offset, sizeof(uint32_t));
       if (HAL_FLASH_Program(FLASH_TYPEPROGRAM_WORD, address, data) == HAL_OK) {
         address += 4;
         offset += 4;
+#else
+#error "Unknown FLASH Program Type."
+      if (0) {}
 #endif
       } else {
         address = address_end + 1;
@@ -328,6 +361,14 @@ void eeprom_buffer_flush(void)
   }
   HAL_FLASH_Lock();
 #endif
+#if defined(ICACHE) && defined (HAL_ICACHE_MODULE_ENABLED) && !defined(HAL_ICACHE_MODULE_DISABLED)
+  if (icache_enabled) {
+    /* Re-enable instruction cache */
+    if (HAL_ICACHE_Enable() != HAL_OK) {
+      Error_Handler();
+    }
+  }
+#endif /* ICACHE && HAL_ICACHE_MODULE_ENABLED && !HAL_ICACHE_MODULE_DISABLED */
 }
 
 #endif /* defined(EEPROM_RETRAM_MODE) */
