@@ -4,7 +4,11 @@
 
 #ifdef STM32H5xx
   #include "stm32h5xx_hal_ramcfg.c"
+#elif STM32U3xx
+  #include "stm32u3xx_hal_ramcfg.c"
 #elif STM32U5xx
   #include "stm32u5xx_hal_ramcfg.c"
+#elif STM32WBAxx
+  #include "stm32wbaxx_hal_ramcfg.c"
 #endif
 #pragma GCC diagnostic pop
