@@ -53,7 +53,7 @@ typedef enum
   HAL_HCD_STATE_TIMEOUT  = 0x04
 } HCD_StateTypeDef;
 
-typedef USB_DRD_TypeDef   HCD_TypeDef;
+typedef USB_DRD_TypeDef         HCD_TypeDef;
 typedef USB_DRD_CfgTypeDef      HCD_InitTypeDef;
 typedef USB_DRD_HCTypeDef       HCD_HCTypeDef;
 typedef USB_DRD_URBStateTypeDef HCD_URBStateTypeDef;
@@ -73,6 +73,7 @@ typedef enum
  * 8Bytes each Block 32Bit in each word
  */
 #define PMA_BLOCKS        ((USB_DRD_PMA_SIZE) / (8U * 32U))
+
 /**
   * @}
   */
@@ -89,11 +90,13 @@ typedef struct
   HCD_TypeDef               *Instance;  /*!< Register base address    */
   HCD_InitTypeDef           Init;       /*!< HCD required parameters  */
   HCD_HCTypeDef             hc[16];     /*!< Host channels parameters */
+
   uint32_t                  ep0_PmaAllocState;  /*!< EP0 PMA allocation State (allocated, virtual Ch, EP0 direction) */
   uint16_t                  phy_chin_state[8];  /*!< Physical Channel in State (Used/Free) */
   uint16_t                  phy_chout_state[8]; /*!< Physical Channel out State (Used/Free)*/
   uint32_t                  PMALookupTable[PMA_BLOCKS]; /*PMA LookUp Table */
   HCD_HostStateTypeDef      HostState; /*!< USB current state DICONNECT/CONNECT/RUN/SUSPEND/RESUME */
+
   HAL_LockTypeDef           Lock;       /*!< HCD peripheral status    */
   __IO HCD_StateTypeDef     State;      /*!< HCD communication state  */
   __IO  uint32_t            ErrorCode;  /*!< HCD Error code           */
@@ -202,7 +205,9 @@ HAL_StatusTypeDef HAL_HCD_HC_Init(HCD_HandleTypeDef *hhcd, uint8_t ch_num,
                                   uint8_t speed, uint8_t ep_type, uint16_t mps);
 
 HAL_StatusTypeDef HAL_HCD_HC_Halt(HCD_HandleTypeDef *hhcd, uint8_t ch_num);
+
 HAL_StatusTypeDef HAL_HCD_HC_Close(HCD_HandleTypeDef *hhcd, uint8_t ch_num);
+
 void              HAL_HCD_MspInit(HCD_HandleTypeDef *hhcd);
 void              HAL_HCD_MspDeInit(HCD_HandleTypeDef *hhcd);
 
@@ -265,6 +270,11 @@ HAL_StatusTypeDef HAL_HCD_HC_SubmitRequest(HCD_HandleTypeDef *hhcd, uint8_t ch_n
                                            uint8_t token, uint8_t *pbuff,
                                            uint16_t length, uint8_t do_ping);
 
+HAL_StatusTypeDef HAL_HCD_HC_SetHubInfo(HCD_HandleTypeDef *hhcd, uint8_t ch_num,
+                                        uint8_t addr, uint8_t PortNbr);
+
+HAL_StatusTypeDef HAL_HCD_HC_ClearHubInfo(HCD_HandleTypeDef *hhcd, uint8_t ch_num);
+
 /* Non-Blocking mode: Interrupt */
 void HAL_HCD_IRQHandler(HCD_HandleTypeDef *hhcd);
 void HAL_HCD_SOF_Callback(HCD_HandleTypeDef *hhcd);
@@ -272,8 +282,10 @@ void HAL_HCD_Connect_Callback(HCD_HandleTypeDef *hhcd);
 void HAL_HCD_Disconnect_Callback(HCD_HandleTypeDef *hhcd);
 void HAL_HCD_PortEnabled_Callback(HCD_HandleTypeDef *hhcd);
 void HAL_HCD_PortDisabled_Callback(HCD_HandleTypeDef *hhcd);
+
 void HAL_HCD_SuspendCallback(HCD_HandleTypeDef *hhcd);
 void HAL_HCD_ResumeCallback(HCD_HandleTypeDef *hhcd);
+
 void HAL_HCD_HC_NotifyURBChange_Callback(HCD_HandleTypeDef *hhcd, uint8_t chnum,
                                          HCD_URBStateTypeDef urb_state);
 /**
@@ -287,9 +299,11 @@ void HAL_HCD_HC_NotifyURBChange_Callback(HCD_HandleTypeDef *hhcd, uint8_t chnum,
 HAL_StatusTypeDef HAL_HCD_ResetPort(HCD_HandleTypeDef *hhcd);
 HAL_StatusTypeDef HAL_HCD_Start(HCD_HandleTypeDef *hhcd);
 HAL_StatusTypeDef HAL_HCD_Stop(HCD_HandleTypeDef *hhcd);
+
 HAL_StatusTypeDef HAL_HCD_Suspend(HCD_HandleTypeDef *hhcd);
 HAL_StatusTypeDef HAL_HCD_Resume(HCD_HandleTypeDef *hhcd);
 HAL_StatusTypeDef HAL_HCD_ResumePort(HCD_HandleTypeDef *hhcd);
+
 /**
   * @}
   */
@@ -298,13 +312,14 @@ HAL_StatusTypeDef HAL_HCD_ResumePort(HCD_HandleTypeDef *hhcd);
 /** @addtogroup HCD_Exported_Functions_Group4 Peripheral State functions
   * @{
   */
-HCD_StateTypeDef        HAL_HCD_GetState(HCD_HandleTypeDef *hhcd);
-HCD_URBStateTypeDef     HAL_HCD_HC_GetURBState(HCD_HandleTypeDef *hhcd, uint8_t chnum);
-HCD_HCStateTypeDef      HAL_HCD_HC_GetState(HCD_HandleTypeDef *hhcd, uint8_t chnum);
-uint32_t                HAL_HCD_HC_GetXferCount(HCD_HandleTypeDef *hhcd, uint8_t chnum);
+HCD_StateTypeDef        HAL_HCD_GetState(HCD_HandleTypeDef const *hhcd);
+HCD_URBStateTypeDef     HAL_HCD_HC_GetURBState(HCD_HandleTypeDef const *hhcd, uint8_t chnum);
+HCD_HCStateTypeDef      HAL_HCD_HC_GetState(HCD_HandleTypeDef const *hhcd, uint8_t chnum);
+uint32_t                HAL_HCD_HC_GetXferCount(HCD_HandleTypeDef const *hhcd, uint8_t chnum);
 uint32_t                HAL_HCD_GetCurrentFrame(HCD_HandleTypeDef *hhcd);
 uint32_t                HAL_HCD_GetCurrentSpeed(HCD_HandleTypeDef *hhcd);
 
+
 /* PMA Allocation functions  **********************************************/
 /** @addtogroup PMA Allocation
   * @{
@@ -318,9 +333,7 @@ HAL_StatusTypeDef  HAL_HCD_PMAReset(HCD_HandleTypeDef *hhcd);
 /**
   * @}
   */
-/**
-  * @}
-  */
+
 
 /**
   * @}
@@ -330,6 +343,10 @@ HAL_StatusTypeDef  HAL_HCD_PMAReset(HCD_HandleTypeDef *hhcd);
 /** @defgroup HCD_Private_Macros HCD Private Macros
   * @{
   */
+
+#define HCD_MIN(a, b)  (((a) < (b)) ? (a) : (b))
+#define HCD_MAX(a, b)  (((a) > (b)) ? (a) : (b))
+
 /** @defgroup HCD_LOGICAL_CHANNEL HCD Logical Channel
   * @{
   */
@@ -475,11 +492,25 @@ HAL_StatusTypeDef  HAL_HCD_PMAReset(HCD_HandleTypeDef *hhcd);
   * @param  bChNum channel Number.
   * @retval Counter value
   */
-__STATIC_INLINE uint16_t HCD_GET_CH_RX_CNT(const HCD_TypeDef *Instance, uint16_t bChNum)
+__STATIC_INLINE uint16_t HCD_GET_CH_RX_CNT(HCD_TypeDef *Instance, uint16_t bChNum)
 {
-  UNUSED(Instance);
+  uint32_t HostCoreSpeed;
   __IO uint32_t count = 10U;
 
+  /* Get Host core Speed */
+  HostCoreSpeed = USB_GetHostSpeed(Instance);
+
+  /* Count depends on device LS */
+  if (HostCoreSpeed == USB_DRD_SPEED_LS)
+  {
+    count = (70U * (HAL_RCC_GetHCLKFreq() / 1000000U)) / 100U;
+  }
+
+  if (count > 15U)
+  {
+    count = HCD_MAX(10U, (count - 15U));
+  }
+
   /* WA: few cycles for RX PMA descriptor to update */
   while (count > 0U)
   {
@@ -543,6 +574,7 @@ __STATIC_INLINE uint16_t HCD_GET_CH_DBUF1_CNT(const HCD_TypeDef *Instance, uint1
   return (uint16_t)USB_DRD_GET_CHEP_DBUF1_CNT((Instance), (bChNum));
 }
 
+
 /**
   * @}
   */
@@ -554,6 +586,9 @@ __STATIC_INLINE uint16_t HCD_GET_CH_DBUF1_CNT(const HCD_TypeDef *Instance, uint1
 /**
   * @}
   */
+/**
+  * @}
+  */
 #endif /* defined (USB_DRD_FS) */
 
 #ifdef __cplusplus
