@@ -484,25 +484,25 @@ typedef  void (*pCRYP_CallbackTypeDef)(CRYP_HandleTypeDef *hcryp);    /*!< point
   *            @arg @ref CRYP_FLAG_KEIF Key error flag
   *            @arg @ref CRYP_FLAG_RWEIF Read/write Error flag
 
-  * @retval The state of __FLAG__ (TRUE or FALSE).
+  * @retval The state of __FLAG__ (FlagStatus).
   */
 
 #define __HAL_CRYP_GET_FLAG(__HANDLE__, __FLAG__) (\
-                                                   ((__FLAG__) == CRYP_FLAG_KEYVALID )?(((__HANDLE__)->Instance->SR \
-                                                       & (CRYP_FLAG_KEYVALID)) == (CRYP_FLAG_KEYVALID)) : \
-                                                   ((__FLAG__) == CRYP_FLAG_BUSY )?(((__HANDLE__)->Instance->SR \
-                                                       & (CRYP_FLAG_BUSY)) == (CRYP_FLAG_BUSY)) : \
-                                                   ((__FLAG__) == CRYP_FLAG_WRERR )?(((__HANDLE__)->Instance->SR \
+                                                   ((__FLAG__) == CRYP_FLAG_KEYVALID )?((((__HANDLE__)->Instance->SR \
+                                                       & (CRYP_FLAG_KEYVALID)) == (CRYP_FLAG_KEYVALID))?SET:RESET) : \
+                                                   ((__FLAG__) == CRYP_FLAG_BUSY )?((((__HANDLE__)->Instance->SR \
+                                                       & (CRYP_FLAG_BUSY)) == (CRYP_FLAG_BUSY))?SET:RESET) : \
+                                                   ((__FLAG__) == CRYP_FLAG_WRERR )?((((__HANDLE__)->Instance->SR \
                                                        & (CRYP_FLAG_WRERR & 0x7FFFFFFFU)) == \
-                                                       (CRYP_FLAG_WRERR & 0x7FFFFFFFU)) : \
-                                                   ((__FLAG__) == CRYP_FLAG_RDERR )?(((__HANDLE__)->Instance->SR \
+                                                       (CRYP_FLAG_WRERR & 0x7FFFFFFFU))?SET:RESET) : \
+                                                   ((__FLAG__) == CRYP_FLAG_RDERR )?((((__HANDLE__)->Instance->SR \
                                                        & (CRYP_FLAG_RDERR & 0x7FFFFFFFU)) == \
-                                                       (CRYP_FLAG_RDERR & 0x7FFFFFFFU)) : \
-                                                   ((__FLAG__) == CRYP_FLAG_KEIF )?(((__HANDLE__)->Instance->ISR \
-                                                       & (CRYP_FLAG_KEIF)) == (CRYP_FLAG_KEIF)) : \
-                                                   ((__FLAG__) == CRYP_FLAG_RWEIF )?(((__HANDLE__)->Instance->ISR \
-                                                       & (CRYP_FLAG_RWEIF)) == (CRYP_FLAG_RWEIF)) : \
-                                                   (((__HANDLE__)->Instance->ISR & (CRYP_FLAG_CCF)) == (CRYP_FLAG_CCF)))
+                                                       (CRYP_FLAG_RDERR & 0x7FFFFFFFU))?SET:RESET) : \
+                                                   ((__FLAG__) == CRYP_FLAG_KEIF )?((((__HANDLE__)->Instance->ISR \
+                                                       & (CRYP_FLAG_KEIF)) == (CRYP_FLAG_KEIF))?SET:RESET) : \
+                                                   ((__FLAG__) == CRYP_FLAG_RWEIF )?((((__HANDLE__)->Instance->ISR \
+                                                       & (CRYP_FLAG_RWEIF)) == (CRYP_FLAG_RWEIF))?SET:RESET) : \
+                                                   ((((__HANDLE__)->Instance->ISR & (CRYP_FLAG_CCF)) == (CRYP_FLAG_CCF)))?SET:RESET)
 
 /** @brief  Clear the CRYP pending status flag.
   * @param  __HANDLE__ specifies the CRYP handle.
