@@ -150,35 +150,35 @@ typedef enum
   */
 typedef struct __SMBUS_HandleTypeDef
 {
-  I2C_TypeDef                 *Instance;        /*!< SMBUS registers base address                  */
+  I2C_TypeDef                 *Instance;        /*!< SMBUS registers base address                            */
 
-  SMBUS_InitTypeDef             Init;           /*!< SMBUS communication parameters              */
+  SMBUS_InitTypeDef             Init;           /*!< SMBUS communication parameters                          */
 
-  uint8_t                       *pBuffPtr;      /*!< Pointer to SMBUS transfer buffer            */
+  uint8_t                       *pBuffPtr;      /*!< Pointer to SMBUS transfer buffer                        */
 
-  uint16_t                      XferSize;       /*!< SMBUS transfer size                         */
+  uint16_t                      XferSize;       /*!< SMBUS transfer size                                     */
 
-  __IO uint16_t                 XferCount;      /*!< SMBUS transfer counter                      */
+  __IO uint16_t                 XferCount;      /*!< SMBUS transfer counter                                  */
 
   __IO uint32_t                 XferOptions;    /*!< SMBUS transfer options this parameter can
-                                                     be a value of @ref SMBUS_OPTIONS            */
+                                                     be a value of @ref SMBUS_XferOptions_definition         */
 
   __IO uint32_t                 PreviousState;  /*!< SMBUS communication Previous state and mode
-                                                     context for internal usage                  */
+                                                     context for internal usage                              */
 
-  HAL_LockTypeDef               Lock;           /*!< SMBUS locking object                        */
+  HAL_LockTypeDef               Lock;           /*!< SMBUS locking object                                    */
 
-  __IO HAL_SMBUS_StateTypeDef   State;          /*!< SMBUS communication state                   */
+  __IO HAL_SMBUS_StateTypeDef   State;          /*!< SMBUS communication state                               */
 
-  __IO HAL_SMBUS_ModeTypeDef    Mode;           /*!< SMBUS communication mode                    */
+  __IO HAL_SMBUS_ModeTypeDef    Mode;           /*!< SMBUS communication mode                                */
 
-  __IO uint32_t                 ErrorCode;      /*!< SMBUS Error code                            */
+  __IO uint32_t                 ErrorCode;      /*!< SMBUS Error code                                        */
 
-  __IO uint32_t                 Devaddress;     /*!< SMBUS Target device address                 */
+  __IO uint32_t                 Devaddress;     /*!< SMBUS Target device address                             */
 
-  __IO uint32_t                 EventCount;     /*!< SMBUS Event counter                         */
+  __IO uint32_t                 EventCount;     /*!< SMBUS Event counter                                     */
 
-  uint8_t                       XferPEC;        /*!< SMBUS PEC data in reception mode            */
+  uint8_t                       XferPEC;        /*!< SMBUS PEC data in reception mode                        */
 
 #if (USE_HAL_SMBUS_REGISTER_CALLBACKS == 1)
   void (* MasterTxCpltCallback)(struct __SMBUS_HandleTypeDef *hsmbus);           /*!< SMBUS Master Tx Transfer completed callback */
@@ -600,6 +600,10 @@ void HAL_SMBUS_ListenCpltCallback(SMBUS_HandleTypeDef *hsmbus);
 void HAL_SMBUS_ErrorCallback(SMBUS_HandleTypeDef *hsmbus);
 void HAL_SMBUS_AbortCpltCallback(SMBUS_HandleTypeDef *hsmbus);
 
+/**
+  * @}
+  */
+
 /**
   * @}
   */
@@ -709,10 +713,6 @@ uint32_t HAL_SMBUS_GetError(SMBUS_HandleTypeDef *hsmbus);
   * @}
   */
 
-/**
-* @}
-*/
-
 #ifdef __cplusplus
 }
 #endif
