@@ -8,6 +8,17 @@
   *           + Initialization and de-initialization functions
   *           + IO operation functions
   *
+  ******************************************************************************
+  * @attention
+  *
+  * Copyright (c) 2019 STMicroelectronics.
+  * All rights reserved.
+  *
+  * This software is licensed under terms that can be found in the LICENSE file
+  * in the root directory of this software component.
+  * If no LICENSE file comes with this software, it is provided AS-IS.
+  *
+  ******************************************************************************
   @verbatim
   ==============================================================================
                     ##### EXTI Peripheral features #####
@@ -72,17 +83,6 @@
 
   @endverbatim
   ******************************************************************************
-  * @attention
-  *
-  * <h2><center>&copy; Copyright (c) 2019 STMicroelectronics.
-  * All rights reserved.</center></h2>
-  *
-  * This software component is licensed by ST under BSD 3-Clause license,
-  * the "License"; You may not use this file except in compliance with the
-  * License. You may obtain a copy of the License at:
-  *                        opensource.org/licenses/BSD-3-Clause
-  *
-  ******************************************************************************
   */
 
 /* Includes ------------------------------------------------------------------*/
@@ -174,7 +174,7 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
   maskline = (1uL << linepos);
 
   /* Configure triggers for configurable lines */
-  if ((pExtiConfig->Line & EXTI_CONFIG) != 0x00u)
+  if ((pExtiConfig->Line & EXTI_CONFIG) != 0x0u)
   {
     assert_param(IS_EXTI_TRIGGER(pExtiConfig->Trigger));
 
@@ -183,7 +183,7 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
     regval = *regaddr;
 
     /* Mask or set line */
-    if ((pExtiConfig->Trigger & EXTI_TRIGGER_RISING) != 0x00u)
+    if ((pExtiConfig->Trigger & EXTI_TRIGGER_RISING) != 0x0u)
     {
       regval |= maskline;
     }
@@ -200,7 +200,7 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
     regval = *regaddr;
 
     /* Mask or set line */
-    if ((pExtiConfig->Trigger & EXTI_TRIGGER_FALLING) != 0x00u)
+    if ((pExtiConfig->Trigger & EXTI_TRIGGER_FALLING) != 0x0u)
     {
       regval |= maskline;
     }
@@ -225,15 +225,16 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
     }
   }
 
+
   /*Set Interrupt And Event Mask for Core 1 if configuration for Core 1 given into parameter mode */
-  if ((pExtiConfig->Mode & EXTI_MODE_C1) != 0x00u)
+  if ((pExtiConfig->Mode & EXTI_MODE_C1) != 0x0u)
   {
     regaddr = (&EXTI->C1IMR1 + (EXTI_MODE_OFFSET * offset));
 
     regval = *regaddr;
 
     /* Mask or set line */
-    if ((pExtiConfig->Mode & EXTI_MODE_INTERRUPT) != 0x00u)
+    if ((pExtiConfig->Mode & EXTI_MODE_INTERRUPT) != 0x0u)
     {
       regval |= maskline;
     }
@@ -244,18 +245,17 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
 
     /* Store interrupt mode */
     *regaddr = regval;
-
   }
 
   /*Set Interrupt And Event Mask for Core 2 if configuration for Core 2 given into parameter mode  */
-  if ((pExtiConfig->Mode & EXTI_MODE_C2) != 0x00u)
+  if ((pExtiConfig->Mode & EXTI_MODE_C2) != 0x0u)
   {
     regaddr = (&EXTI->C2IMR1 + (EXTI_MODE_OFFSET * offset));
 
     regval = *regaddr;
 
     /* Mask or set line */
-    if ((pExtiConfig->Mode & EXTI_MODE_INTERRUPT) != 0x00u)
+    if ((pExtiConfig->Mode & EXTI_MODE_INTERRUPT) != 0x0u)
     {
       regval |= maskline;
     }
@@ -275,7 +275,7 @@ HAL_StatusTypeDef HAL_EXTI_SetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
     regval = *regaddr;
 
     /* Mask or set line */
-    if ((pExtiConfig->Mode & EXTI_MODE_EVENT) != 0x00u)
+    if ((pExtiConfig->Mode & EXTI_MODE_EVENT) != 0x0u)
     {
       regval |= maskline;
     }
@@ -323,12 +323,13 @@ HAL_StatusTypeDef HAL_EXTI_GetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
   linepos = (pExtiConfig->Line & EXTI_PIN_MASK);
   maskline = (1uL << linepos);
 
+
   /* 1] Get core 1 mode : interrupt */
   regaddr = (&EXTI->C1IMR1 + (EXTI_MODE_OFFSET * offset));
   regval = *regaddr;
 
   /* Check if selected line is enable */
-  if ((regval & maskline) != 0x00u)
+  if ((regval & maskline) != 0x0u)
   {
     pExtiConfig->Mode = EXTI_MODE_C1_INTERRUPT;
   }
@@ -342,7 +343,7 @@ HAL_StatusTypeDef HAL_EXTI_GetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
   regval = *regaddr;
 
   /* Check if selected line is enable */
-  if ((regval & maskline) != 0x00u)
+  if ((regval & maskline) != 0x0u)
   {
     pExtiConfig->Mode |= EXTI_MODE_C2_INTERRUPT;
   }
@@ -356,33 +357,33 @@ HAL_StatusTypeDef HAL_EXTI_GetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
   regval = *regaddr;
 
   /* Check if selected line is enable */
-  if ((regval & maskline) != 0x00u)
+  if ((regval & maskline) != 0x0u)
   {
     pExtiConfig->Mode |= EXTI_MODE_C2_EVENT;
   }
 
+  /* Get default Trigger and GPIOSel configuration */
+  pExtiConfig->Trigger = EXTI_TRIGGER_NONE;
+  pExtiConfig->GPIOSel = 0x0u;
+
   /* 2] Get trigger for configurable lines : rising */
-  if ((pExtiConfig->Line & EXTI_CONFIG) != 0x00u)
+  if ((pExtiConfig->Line & EXTI_CONFIG) != 0x0u)
   {
     regaddr = (&EXTI->RTSR1 + (EXTI_CONFIG_OFFSET * offset));
     regval = *regaddr;
 
     /* Check if configuration of selected line is enable */
-    if ((regval & maskline) != 0x00u)
+    if ((regval & maskline) != 0x0u)
     {
       pExtiConfig->Trigger = EXTI_TRIGGER_RISING;
     }
-    else
-    {
-      pExtiConfig->Trigger = EXTI_TRIGGER_NONE;
-    }
 
     /* Get falling configuration */
     regaddr = (&EXTI->FTSR1 + (EXTI_CONFIG_OFFSET * offset));
     regval = *regaddr;
 
     /* Check if configuration of selected line is enable */
-    if ((regval & maskline) != 0x00u)
+    if ((regval & maskline) != 0x0u)
     {
       pExtiConfig->Trigger |= EXTI_TRIGGER_FALLING;
     }
@@ -395,15 +396,6 @@ HAL_StatusTypeDef HAL_EXTI_GetConfigLine(EXTI_HandleTypeDef *hexti, EXTI_ConfigT
       regval = EXTI->EXTICR[linepos >> 2u];
       pExtiConfig->GPIOSel = ((regval << (EXTI_EXTICR1_EXTI1_Pos * (3uL - (linepos & 0x03u)))) >> 24);
     }
-    else
-    {
-      pExtiConfig->GPIOSel = 0x00u;
-    }
-  }
-  else
-  {
-    pExtiConfig->Trigger = EXTI_TRIGGER_NONE;
-    pExtiConfig->GPIOSel = 0x00u;
   }
 
   return HAL_OK;
@@ -447,13 +439,12 @@ HAL_StatusTypeDef HAL_EXTI_ClearConfigLine(EXTI_HandleTypeDef *hexti)
   *regaddr = regval;
 
   /* 2] Clear event mode */
-
   regaddr = (&EXTI->C2EMR1 + (EXTI_MODE_OFFSET * offset));
   regval = (*regaddr & ~maskline);
   *regaddr = regval;
 
   /* 3] Clear triggers in case of configurable lines */
-  if ((hexti->Line & EXTI_CONFIG) != 0x00u)
+  if ((hexti->Line & EXTI_CONFIG) != 0x0u)
   {
     regaddr = (&EXTI->RTSR1 + (EXTI_CONFIG_OFFSET * offset));
     regval = (*regaddr & ~maskline);
@@ -577,7 +568,7 @@ void HAL_EXTI_IRQHandler(EXTI_HandleTypeDef *hexti)
   regaddr = (&EXTI->RPR1 + (EXTI_CONFIG_OFFSET * offset));
   regval = (*regaddr & maskline);
 
-  if (regval != 0x00u)
+  if (regval != 0x0u)
   {
     /* Clear pending bit */
     *regaddr = maskline;
@@ -593,7 +584,7 @@ void HAL_EXTI_IRQHandler(EXTI_HandleTypeDef *hexti)
   regaddr = (&EXTI->FPR1 + (EXTI_CONFIG_OFFSET * offset));
   regval = (*regaddr & maskline);
 
-  if (regval != 0x00u)
+  if (regval != 0x0u)
   {
     /* Clear pending bit */
     *regaddr = maskline;
@@ -731,5 +722,3 @@ void HAL_EXTI_GenerateSWI(EXTI_HandleTypeDef *hexti)
 /**
   * @}
   */
-
-/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
