@@ -610,7 +610,7 @@ ErrorStatus LL_ADC_DeInit(ADC_TypeDef *ADCx)
 
     /* Reset register CFGR2 */
     CLEAR_BIT(ADCx->CFGR2,
-              (  ADC_CFGR2_LSHIFT  | ADC_CFGR2_OVSR    | ADC_CFGR2_RSHIFT1
+              (  ADC_CFGR2_LSHIFT  | ADC_CFGR2_OSVR    | ADC_CFGR2_RSHIFT1
                | ADC_CFGR2_RSHIFT4 | ADC_CFGR2_RSHIFT3 | ADC_CFGR2_RSHIFT2
                | ADC_CFGR2_RSHIFT1 | ADC_CFGR2_ROVSM   | ADC_CFGR2_TROVS
                | ADC_CFGR2_OVSS    | ADC_CFGR2_JOVSE | ADC_CFGR2_ROVSE)
@@ -632,13 +632,13 @@ ErrorStatus LL_ADC_DeInit(ADC_TypeDef *ADCx)
              );
 
     /* Reset register TR1 */
-    CLEAR_BIT(ADCx->LTR1, ADC_LTR1_LT1);
-    SET_BIT(ADCx->HTR1, ADC_HTR1_HT1);
+    CLEAR_BIT(ADCx->LTR1, ADC_LTR1_LTR1);
+    SET_BIT(ADCx->HTR1, ADC_HTR1_HTR1);
 
-    CLEAR_BIT(ADCx->LTR2, ADC_LTR2_LT2);
-    SET_BIT(ADCx->HTR2, ADC_HTR2_HT2);
-    CLEAR_BIT(ADCx->LTR3, ADC_LTR3_LT3);
-    SET_BIT(ADCx->HTR3, ADC_HTR3_HT3);
+    CLEAR_BIT(ADCx->LTR2, ADC_LTR2_LTR2);
+    SET_BIT(ADCx->HTR2, ADC_HTR2_HTR2);
+    CLEAR_BIT(ADCx->LTR3, ADC_LTR3_LTR3);
+    SET_BIT(ADCx->HTR3, ADC_HTR3_HTR3);
 
     /* Reset register SQR1 */
     CLEAR_BIT(ADCx->SQR1,
