@@ -6,13 +6,12 @@
   ******************************************************************************
   * @attention
   *
-  * <h2><center>&copy; Copyright (c) 2015 STMicroelectronics.
-  * All rights reserved.</center></h2>
+  * Copyright (c) 2015 STMicroelectronics.
+  * All rights reserved.
   *
-  * This software component is licensed by ST under Ultimate Liberty license
-  * SLA0044, the "License"; You may not use this file except in compliance with
-  * the License. You may obtain a copy of the License at:
-  *                      www.st.com/SLA0044
+  * This software is licensed under terms that can be found in the LICENSE file
+  * in the root directory of this software component.
+  * If no LICENSE file comes with this software, it is provided AS-IS.
   *
   ******************************************************************************
   */
@@ -29,75 +28,75 @@ EndBSPDependencies */
 #include "usbh_msc.h"
 
 /** @addtogroup USBH_LIB
-* @{
-*/
+  * @{
+  */
 
 /** @addtogroup USBH_CLASS
-* @{
-*/
+  * @{
+  */
 
 /** @addtogroup USBH_MSC_CLASS
-* @{
-*/
+  * @{
+  */
 
 /** @defgroup USBH_MSC_BOT
-* @brief    This file includes the mass storage related functions
-* @{
-*/
+  * @brief    This file includes the mass storage related functions
+  * @{
+  */
 
 
 /** @defgroup USBH_MSC_BOT_Private_TypesDefinitions
-* @{
-*/
+  * @{
+  */
 /**
-* @}
-*/
+  * @}
+  */
 
 /** @defgroup USBH_MSC_BOT_Private_Defines
-* @{
-*/
+  * @{
+  */
 /**
-* @}
-*/
+  * @}
+  */
 
 /** @defgroup USBH_MSC_BOT_Private_Macros
-* @{
-*/
+  * @{
+  */
 /**
-* @}
-*/
+  * @}
+  */
 
 
 /** @defgroup USBH_MSC_BOT_Private_Variables
-* @{
-*/
+  * @{
+  */
 
 /**
-* @}
-*/
+  * @}
+  */
 
 
 /** @defgroup USBH_MSC_BOT_Private_FunctionPrototypes
-* @{
-*/
+  * @{
+  */
 static USBH_StatusTypeDef USBH_MSC_BOT_Abort(USBH_HandleTypeDef *phost, uint8_t lun, uint8_t dir);
 static BOT_CSWStatusTypeDef USBH_MSC_DecodeCSW(USBH_HandleTypeDef *phost);
 /**
-* @}
-*/
+  * @}
+  */
 
 
 /** @defgroup USBH_MSC_BOT_Exported_Variables
-* @{
-*/
+  * @{
+  */
 /**
-* @}
-*/
+  * @}
+  */
 
 
 /** @defgroup USBH_MSC_BOT_Private_Functions
-* @{
-*/
+  * @{
+  */
 
 /**
   * @brief  USBH_MSC_BOT_REQ_Reset
@@ -116,7 +115,7 @@ USBH_StatusTypeDef USBH_MSC_BOT_REQ_Reset(USBH_HandleTypeDef *phost)
   phost->Control.setup.b.wIndex.w = 0U;
   phost->Control.setup.b.wLength.w = 0U;
 
-  return USBH_CtlReq(phost, 0U, 0U);
+  return USBH_CtlReq(phost, NULL, 0U);
 }
 
 /**
@@ -183,8 +182,8 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
     case BOT_SEND_CBW:
       MSC_Handle->hbot.cbw.field.LUN = lun;
       MSC_Handle->hbot.state = BOT_SEND_CBW_WAIT;
-      USBH_BulkSendData(phost, MSC_Handle->hbot.cbw.data,
-                        BOT_CBW_LENGTH, MSC_Handle->OutPipe, 1U);
+      (void)USBH_BulkSendData(phost, MSC_Handle->hbot.cbw.data,
+                              BOT_CBW_LENGTH, MSC_Handle->OutPipe, 1U);
 
       break;
 
@@ -208,7 +207,6 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
             MSC_Handle->hbot.state = BOT_DATA_OUT;
           }
         }
-
         else
         {
           /* If there is NO Data Transfer Stage */
@@ -216,13 +214,8 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         }
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
       else if (URB_Status == USBH_URB_NOTREADY)
       {
@@ -230,36 +223,31 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         MSC_Handle->hbot.state = BOT_SEND_CBW;
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
       else
       {
         if (URB_Status == USBH_URB_STALL)
         {
-          MSC_Handle->hbot.state  = BOT_ERROR_OUT;
+          MSC_Handle->hbot.state = BOT_ERROR_OUT;
 
 #if (USBH_USE_OS == 1U)
-          phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-          (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-          (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+          USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
         }
       }
       break;
 
     case BOT_DATA_IN:
+
       /* Send first packet */
-      USBH_BulkReceiveData(phost, MSC_Handle->hbot.pbuf,
-                           MSC_Handle->InEpSize, MSC_Handle->InPipe);
+      (void)USBH_BulkReceiveData(phost, MSC_Handle->hbot.pbuf,
+                                 MSC_Handle->InEpSize, MSC_Handle->InPipe);
+
+#if defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U)
+      phost->NakTimer = phost->Timer;
+#endif /* defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U) */
 
       MSC_Handle->hbot.state = BOT_DATA_IN_WAIT;
 
@@ -286,24 +274,39 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         if (MSC_Handle->hbot.cbw.field.DataTransferLength > 0U)
         {
           /* Send next packet */
-          USBH_BulkReceiveData(phost, MSC_Handle->hbot.pbuf,
-                               MSC_Handle->InEpSize, MSC_Handle->InPipe);
+          (void)USBH_BulkReceiveData(phost, MSC_Handle->hbot.pbuf,
+                                     MSC_Handle->InEpSize, MSC_Handle->InPipe);
+
+#if defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U)
+           phost->NakTimer = phost->Timer;
+#endif /* defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U) */
         }
         else
         {
           /* If value was 0, and successful transfer, then change the state */
-          MSC_Handle->hbot.state  = BOT_RECEIVE_CSW;
+          MSC_Handle->hbot.state = BOT_RECEIVE_CSW;
 
 #if (USBH_USE_OS == 1U)
-          phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-          (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-          (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+          USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
         }
       }
+#if defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U)
+      else if (URB_Status == USBH_URB_NAK_WAIT)
+      {
+        MSC_Handle->hbot.state = BOT_DATA_IN_WAIT;
+
+        if ((phost->Timer - phost->NakTimer) > phost->NakTimeout)
+        {
+          phost->NakTimer = phost->Timer;
+          USBH_ActivatePipe(phost, MSC_Handle->InPipe);
+        }
+
+#if (USBH_USE_OS == 1U)
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
+      }
+#endif /* defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U) */
       else if (URB_Status == USBH_URB_STALL)
       {
         /* This is Data IN Stage STALL Condition */
@@ -317,13 +320,8 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         4. The host shall attempt to receive a CSW.*/
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
       else
       {
@@ -332,8 +330,8 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
 
     case BOT_DATA_OUT:
 
-      USBH_BulkSendData(phost, MSC_Handle->hbot.pbuf,
-                        MSC_Handle->OutEpSize, MSC_Handle->OutPipe, 1U);
+      (void)USBH_BulkSendData(phost, MSC_Handle->hbot.pbuf,
+                              MSC_Handle->OutEpSize, MSC_Handle->OutPipe, 1U);
 
       MSC_Handle->hbot.state  = BOT_DATA_OUT_WAIT;
       break;
@@ -357,43 +355,33 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         /* More Data To be Sent */
         if (MSC_Handle->hbot.cbw.field.DataTransferLength > 0U)
         {
-          USBH_BulkSendData(phost, MSC_Handle->hbot.pbuf,
-                            MSC_Handle->OutEpSize, MSC_Handle->OutPipe, 1U);
+          (void)USBH_BulkSendData(phost, MSC_Handle->hbot.pbuf,
+                                  MSC_Handle->OutEpSize, MSC_Handle->OutPipe, 1U);
         }
         else
         {
           /* If value was 0, and successful transfer, then change the state */
-          MSC_Handle->hbot.state  = BOT_RECEIVE_CSW;
+          MSC_Handle->hbot.state = BOT_RECEIVE_CSW;
         }
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
 
       else if (URB_Status == USBH_URB_NOTREADY)
       {
         /* Resend same data */
-        MSC_Handle->hbot.state  = BOT_DATA_OUT;
+        MSC_Handle->hbot.state = BOT_DATA_OUT;
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
 
       else if (URB_Status == USBH_URB_STALL)
       {
-        MSC_Handle->hbot.state  = BOT_ERROR_OUT;
+        MSC_Handle->hbot.state = BOT_ERROR_OUT;
 
         /* Refer to USB Mass-Storage Class : BOT (www.usb.org)
         6.7.3 Ho - Host expects to send data to the device
@@ -403,13 +391,8 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         */
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
       else
       {
@@ -418,10 +401,14 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
 
     case BOT_RECEIVE_CSW:
 
-      USBH_BulkReceiveData(phost, MSC_Handle->hbot.csw.data,
-                           BOT_CSW_LENGTH, MSC_Handle->InPipe);
+      (void)USBH_BulkReceiveData(phost, MSC_Handle->hbot.csw.data,
+                                 BOT_CSW_LENGTH, MSC_Handle->InPipe);
 
-      MSC_Handle->hbot.state  = BOT_RECEIVE_CSW_WAIT;
+      MSC_Handle->hbot.state = BOT_RECEIVE_CSW_WAIT;
+
+#if defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U)
+      phost->NakTimer = phost->Timer;
+#endif /* defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U) */
       break;
 
     case BOT_RECEIVE_CSW_WAIT:
@@ -445,26 +432,32 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
         }
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
-      else if (URB_Status == USBH_URB_STALL)
+#if defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U)
+      else if (URB_Status == USBH_URB_NAK_WAIT)
       {
-        MSC_Handle->hbot.state  = BOT_ERROR_IN;
+        MSC_Handle->hbot.state = BOT_RECEIVE_CSW_WAIT;
+
+        if ((phost->Timer - phost->NakTimer) > phost->NakTimeout)
+        {
+          phost->NakTimer = phost->Timer;
+          USBH_ActivatePipe(phost, MSC_Handle->InPipe);
+        }
 
 #if (USBH_USE_OS == 1U)
-        phost->os_msg = (uint32_t)USBH_URB_EVENT;
-#if (osCMSIS < 0x20000U)
-        (void)osMessagePut(phost->os_event, phost->os_msg, 0U);
-#else
-        (void)osMessageQueuePut(phost->os_event, &phost->os_msg, 0U, NULL);
-#endif
-#endif
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
+      }
+#endif /* defined (USBH_IN_NAK_PROCESS) && (USBH_IN_NAK_PROCESS == 1U) */
+      else if (URB_Status == USBH_URB_STALL)
+      {
+        MSC_Handle->hbot.state = BOT_ERROR_IN;
+
+#if (USBH_USE_OS == 1U)
+        USBH_OS_PutMessage(phost, USBH_URB_EVENT, 0U, 0U);
+#endif /* (USBH_USE_OS == 1U) */
       }
       else
       {
@@ -493,10 +486,9 @@ USBH_StatusTypeDef USBH_MSC_BOT_Process(USBH_HandleTypeDef *phost, uint8_t lun)
 
       if (error == USBH_OK)
       {
-
         toggle = USBH_LL_GetToggle(phost, MSC_Handle->OutPipe);
-        USBH_LL_SetToggle(phost, MSC_Handle->OutPipe, 1U - toggle);
-        USBH_LL_SetToggle(phost, MSC_Handle->InPipe, 0U);
+        (void)USBH_LL_SetToggle(phost, MSC_Handle->OutPipe, 1U - toggle);
+        (void)USBH_LL_SetToggle(phost, MSC_Handle->InPipe, 0U);
         MSC_Handle->hbot.state = BOT_ERROR_IN;
       }
       else
@@ -590,7 +582,6 @@ static BOT_CSWStatusTypeDef USBH_MSC_DecodeCSW(USBH_HandleTypeDef *phost)
     (11) Ho > Do  (Host expects to send data to the device,
     Device intends to receive data from the host)*/
 
-
     status = BOT_CSW_PHASE_ERROR;
   }
   else
@@ -626,7 +617,6 @@ static BOT_CSWStatusTypeDef USBH_MSC_DecodeCSW(USBH_HandleTypeDef *phost)
           Device intends to send data to the host)
           (12) Ho = Do (Host expects to send data to the device,
           Device intends to receive data from the host)
-
           */
 
           status = BOT_CSW_CMD_PASSED;
@@ -635,7 +625,6 @@ static BOT_CSWStatusTypeDef USBH_MSC_DecodeCSW(USBH_HandleTypeDef *phost)
         {
           status = BOT_CSW_CMD_FAILED;
         }
-
         else if (MSC_Handle->hbot.csw.field.Status == 2U)
         {
           /* Refer to USB Mass-Storage Class : BOT (www.usb.org)
@@ -675,26 +664,24 @@ static BOT_CSWStatusTypeDef USBH_MSC_DecodeCSW(USBH_HandleTypeDef *phost)
 
 
 /**
-* @}
-*/
+  * @}
+  */
 
 /**
-* @}
-*/
+  * @}
+  */
 
 /**
-* @}
-*/
+  * @}
+  */
 
 /**
-* @}
-*/
+  * @}
+  */
 
 /**
-* @}
-*/
-
-/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
+  * @}
+  */
 
 
 
