@@ -1,6 +1,6 @@
 /*
  *******************************************************************************
- * Copyright (c) 2020-2021, STMicroelectronics
+ * Copyright (c) 2020, STMicroelectronics
  * All rights reserved.
  *
  * This software component is licensed by ST under BSD 3-Clause license,
@@ -77,6 +77,7 @@
 #define PA7_ALT1                (PA7  | ALT1)
 #define PA7_ALT2                (PA7  | ALT2)
 #define PA7_ALT3                (PA7  | ALT3)
+#define PA8_ALT1                (PA8  | ALT1)
 #define PA9_ALT1                (PA9  | ALT1)
 #define PA10_ALT1               (PA10 | ALT1)
 #define PA11_ALT1               (PA11 | ALT1)
@@ -97,9 +98,7 @@
 #define PB6_ALT2                (PB6  | ALT2)
 #define PB7_ALT1                (PB7  | ALT1)
 #define PB8_ALT1                (PB8  | ALT1)
-#define PB8_ALT2                (PB8  | ALT2)
 #define PB9_ALT1                (PB9  | ALT1)
-#define PB9_ALT2                (PB9  | ALT2)
 #define PB14_ALT1               (PB14 | ALT1)
 #define PB14_ALT2               (PB14 | ALT2)
 #define PB15_ALT1               (PB15 | ALT1)
@@ -111,9 +110,7 @@
 #define PC4_ALT1                (PC4  | ALT1)
 #define PC5_ALT1                (PC5  | ALT1)
 #define PC6_ALT1                (PC6  | ALT1)
-#define PC6_ALT2                (PC6  | ALT2)
 #define PC7_ALT1                (PC7  | ALT1)
-#define PC7_ALT2                (PC7  | ALT2)
 #define PC9_ALT1                (PC9  | ALT1)
 #define PC10_ALT1               (PC10 | ALT1)
 #define PC11_ALT1               (PC11 | ALT1)
